@@ -5,3 +5,6 @@ pub use wait::{wait, wait_random};
 
 mod generic_codec;
 pub use generic_codec::GenericCodec;
+
+#[cfg(feature = "test")]
+pub mod test;
